@@ -26,7 +26,6 @@ from queue import Queue
 ERR__refresh_expired = "Token too old to be used for refresh. Please authenticate again"
 ERR__incorrect_install_key = "Incorrect install key!"
 ERR__invalid_level = "Invalid level!"
-ERR__denied_create_user = "Cannot create that user with your current permissions"
 ERR__incorrect_credentials = "Incorrect credentials!"
 ERR__email_template_not_installed = "Either email template does not exist or email template has not been attached to this application configuration"
 ERR__lacking_permissions = "Only an administrator can perform this action!"
@@ -638,11 +637,15 @@ class JAAQLModel(BaseJAAQLModel):
 
         return res
 
-    def create_account(self, connection: DBInterface, inputs: dict, password: str = None, is_public: bool = False):
+    def create_account(self, connection: DBInterface, inputs: dict, is_public: bool = False):
         if inputs.get(KEY__password) is not None and not is_public:
             crypt_utils.validate_password(inputs[KEY__password])
 
         inputs[KEY__is_public] = is_public
+        password = inputs.pop(KEY__password, None)
+
+        if KEY__attach_as not in inputs:
+            inputs[KEY__attach_as] = None
 
         account_id = execute_supplied_statement_singleton(connection, QUERY__create_account, inputs,
                                                           encryption_key=self.get_db_crypt_key(), encrypt_parameters=[KEY__username],
@@ -707,7 +710,7 @@ class JAAQLModel(BaseJAAQLModel):
             self.add_account_password(ROLE__postgres, super_db_password)
             self.add_account_password(ROLE__jaaql, jaaql_password)
 
-            self.create_account(self.jaaql_lookup_connection, {KEY__username: USERNAME__public}, PASSWORD__public, True)
+            self.create_account(self.jaaql_lookup_connection, {KEY__username: USERNAME__public, KEY__password: PASSWORD__public})
 
             self.jaaql_lookup_connection.close()
 
@@ -839,8 +842,7 @@ class JAAQLModel(BaseJAAQLModel):
         return crypt_utils.jwt_encode(self.vault.get_obj(VAULT_KEY__jwt_crypt_key), jwt_data, JWT_PURPOSE__oauth, expiry_ms=self.token_expiry_ms)
 
     def fetch_pivoted_application_schemas(self):
-        data = execute_supplied_statement(self.jaaql_lookup_connection, QUERY__fetch_application_schemas, as_objects=True,
-                                          skip_commit=True)
+        data = execute_supplied_statement(self.jaaql_lookup_connection, QUERY__fetch_application_schemas, as_objects=True, skip_commit=True)
 
         return self.group(self.pivot(data,
                           [JAAQLPivotInfo(KEY__configuration, "name", "configuration_name"),
